import logging
from pathlib import Path

from colorama import init as c_init

from .coloured_formatter import ColouredFormatter


def init(
    root_path: Path, show_console: bool = True, console_level: int = logging.INFO, file_level=logging.DEBUG
) -> None:
    LOG_DIR = root_path.joinpath("logs")
    root = logging.getLogger()
    logger = logging.getLogger("Painted-Logger")

    if show_console:
        c_init(autoreset=True, strip=False)
        stream_logger = logging.StreamHandler()
        stream_logger.setLevel(console_level)
        stream_logger.setFormatter(ColouredFormatter())
        root.addHandler(stream_logger)

    LOG_DIR.mkdir(exist_ok=True)
    file_logger = logging.FileHandler(filename=LOG_DIR.joinpath(f"{root_path.name}.log"), encoding="UTF-8")
    file_logger.setLevel(file_level)
    formatter = logging.Formatter(
        fmt="[%(asctime)s] [%(levelname)-8s] {%(name)s:%(filename)s:%(lineno)d} | %(message)s",
        datefmt="%Y-%m-%d %H:%M:%S",
    )
    file_logger.setFormatter(formatter)
    root.addHandler(file_logger)

    root.setLevel(logging.NOTSET)
    logger.log(logging.DEBUG, "DEBUG is Visible")
    logger.log(logging.INFO, "INFO is Visible")
    logger.log(logging.WARNING, "WARNING is Visible")
    logger.log(logging.ERROR, "ERROR is Visible")
    logger.log(logging.CRITICAL, "CRITICAL is Visible")
